@@ -8,11 +8,11 @@
 #include <QObject>
 #include <QTest>
 
-#include <aktest.h>
-#include <storage/dbexception.h>
-#include <storage/dbintrospector.h>
+#include "aktest.h"
+#include "storage/dbexception.h"
+#include "storage/dbintrospector.h"
 
-#define QL1S(x) QLatin1String(x)
+#define QL1S(x) QLatin1StringView(x)
 
 using namespace Akonadi::Server;
 
