@@ -4,7 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <shared/akremotelog.h>
+#include "shared/akremotelog.h"
 
 #include <QCoreApplication>
 #include <QThread>
